Binary and bitstring representation.
This brief implements inline heap binaries: a boxed binary header, followed by the byte length and byte data packed directly into heap words.
Structs
- Binary
- Borrowed accessor for an inline heap binary.
Functions
- packed_
word_ count - Number of heap words required to store
byte_lenbytes. - write_
binary - Writes an inline binary layout (
header, byte_len, packed bytes...) intoheap.